get_exchange_rates: Look up the historical values of base currency in another...

Description Usage Arguments Value Examples

View source: R/get_exchange_rates.R

Description

Look up the historical values of base currency in another currency.

Usage

1
2
3
4
5
6
7
get_exchange_rates(
  base = "USD",
  symbols = "HUF",
  start_date = Sys.Date() - 30,
  end_date = Sys.Date(),
  retried = 0
)

Arguments

base

date

symbols

date

start_date

currency symbol

end_date

currency symbol

retried

number of times the function already failed

Value

data.table object

Examples

1
2
3
get_exchange_rates()
get_exchange_rates(base= 'USD', symbols='EUR')
get_exchange_rates(base= 'USD', symbols='GBP', start_date= "2021-04-24", end_date= "2021-05-10")

Deborah-Jia/m_r_skills documentation built on Dec. 17, 2021, 4:10 p.m.